@@ -1,5 +1,5 @@
 package Net::Whois::Raw;
-$Net::Whois::Raw::VERSION = '2.99018';
+$Net::Whois::Raw::VERSION = '2.99019';
 # ABSTRACT: Get Whois information of domains and IP addresses.
 
 require 5.008_001;
@@ -182,7 +182,7 @@ sub recursive_whois {
         elsif ( $whois =~ /To single out one record, look it up with \"xxx\",/s ) {
             return recursive_whois( "=$dom", $srv, $was_srv );
         }
-        elsif ( my ( $rs ) = _referral_server() && !$norecurse ) {
+        elsif ( !$norecurse && ( my ( $rs ) = _referral_server() ) ) {
             $newsrv = $rs;
             last;
         }
@@ -479,7 +479,7 @@ Net::Whois::Raw - Get Whois information of domains and IP addresses.
 
 =head1 VERSION
 
-version 2.99018
+version 2.99019
 
 =head1 SYNOPSIS
 
